@@ -1,23 +1,30 @@
 package List::Util::Uniq;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-31'; # DATE
-our $DIST = 'List-Util-Uniq'; # DIST
-our $VERSION = '0.004'; # VERSION
-
 use strict;
 use warnings;
 
-require Exporter;
-our @ISA = qw(Exporter);
+use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-06-20'; # DATE
+our $DIST = 'List-Util-Uniq'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 our @EXPORT_OK = qw(
-                           uniq_adj
-                           uniq_adj_ci
-                           uniq_ci
-                           is_uniq
-                           is_uniq_ci
-                           is_monovalued
-                           is_monovalued_ci
+                       uniq
+                       uniqnum
+                       uniqstr
+
+                       uniq_adj
+                       uniq_adj_ci
+                       uniq_ci
+                       is_uniq
+                       is_uniq_ci
+                       is_monovalued
+                       is_monovalued_ci
+                       dupe
+                       dupenum
+                       dupestr
                );
 
 sub uniq_adj {
@@ -101,6 +108,44 @@ sub is_monovalued_ci {
     1;
 }
 
+sub uniqstr {
+    my (@uniqs, %vals);
+    for (@_) {
+        ++$vals{$_} == 1 and push @uniqs, $_;
+    }
+    @uniqs;
+}
+
+sub uniqnum {
+    my (@uniqs, %vals);
+    for (@_) {
+        no warnings 'numeric';
+        ++$vals{$_+0} == 1 and push @uniqs, $_;
+    }
+    @uniqs;
+}
+
+sub uniq { goto \&uniqstr }
+
+sub dupestr {
+    my (@dupes, %vals);
+    for (@_) {
+        ++$vals{$_} > 1 and push @dupes, $_;
+    }
+    @dupes;
+}
+
+sub dupenum {
+    my (@dupes, %vals);
+    for (@_) {
+        no warnings 'numeric';
+        ++$vals{$_+0} > 1 and push @dupes, $_;
+    }
+    @dupes;
+}
+
+sub dupe { goto \&dupestr }
+
 1;
 # ABSTRACT: List utilities related to finding unique items
 
@@ -116,7 +161,7 @@ List::Util::Uniq - List utilities related to finding unique items
 
 =head1 VERSION
 
-This document describes version 0.004 of List::Util::Uniq (from Perl distribution List-Util-Uniq), released on 2021-07-31.
+This document describes version 0.005 of List::Util::Uniq (from Perl distribution List-Util-Uniq), released on 2023-06-20.
 
 =head1 SYNOPSIS
 
@@ -128,25 +173,35 @@ This document describes version 0.004 of List::Util::Uniq (from Perl distributio
      uniq_adj
      uniq_adj_ci
      uniq_ci
+     dupe
+     dupenum
+     dupestr
  );
 
- $res = is_monovalued(qw/a a a/); # 1
- $res = is_monovalued(qw/a b a/); # 0
+ $res = is_monovalued(qw/a a a/); # => 1
+ $res = is_monovalued(qw/a b a/); # => 0
 
- $res = is_monovalued_ci(qw/a a A/); # 1
- $res = is_monovalued_ci(qw/a b A/); # 0
+ $res = is_monovalued_ci(qw/a a A/); # => 1
+ $res = is_monovalued_ci(qw/a b A/); # => 0
 
- $res = is_uniq(qw/a b a/); # 0
- $res = is_uniq(qw/a b c/); # 1
+ $res = is_uniq(qw/a b a/); # => 0
+ $res = is_uniq(qw/a b c/); # => 1
 
- $res = is_uniq_ci(qw/a b A/); # 0
- $res = is_uniq_ci(qw/a b c/); # 1
+ $res = is_uniq_ci(qw/a b A/); # => 0
+ $res = is_uniq_ci(qw/a b c/); # => 1
 
- @res = uniq_adj(1, 4, 4, 3, 1, 1, 2); # 1, 4, 3, 1, 2
+ @res = uniq_adj(1, 4, 4, 3, 1, 1, 2); # => (1, 4, 3, 1, 2)
 
- @res = uniq_adj_ci("a", "b", "B", "c", "a"); # "a", "b", "c", "a"
+ @res = uniq_adj_ci("a", "b", "B", "c", "a"); # => ("a", "b", "c", "a")
 
- @res = uniq_ci("a", "b", "B", "c", "a"); # "a", "b", "c"
+ @res = uniq_ci("a", "b", "B", "c", "a"); #  => ("a", "b", "c")
+
+ @res = dupe("a","b","a","a","b","c"); #  => ("a","a","b")
+ @res = dupenum(1,2,1,1,2,3); #  => (1,1,2)
+ @res = dupenum("a",0,0.0,1); #  => (0,0.0), because "a" becomes 0 numerically
+ @res = dupestr("a","b","a","a","b","c"); # => ("a","a","b")
+
+=for Pod::Coverage ^(uniq|uniqnum|uniqstr)+
 
 =head1 FUNCTIONS
 
@@ -208,6 +263,35 @@ is_monovalued(undef, undef) >> return true.
 
 Like L</is_monovalued> except case-insensitive.
 
+=head2 dupe
+
+See L</dupestr>.
+
+=head2 dupestr
+
+Usage:
+
+ @dupes = dupestr(@list);
+
+Return duplicate elements (the second and subsequence occurrences of each
+element) in C<@list>. If you only want to list each duplicate elements once, you
+can do:
+
+ @uniq_dupes = uniqstr(dupestr(@list));
+
+where C<uniqstr> can be found in L<List::Util>, but the pure-perl version is
+also provided by this module, for convenience.
+
+=head2 dupenum
+
+Like L</dupestr> but the values are compared numerically. If you only want to
+list each duplicate elements once, you can do:
+
+ @uniq_dupes = uniqnum(dupenum(@list));
+
+where C<uniqnum> can be found in L<List::Util>, but the pure-perl version is
+also provided by this module, for convenience.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/List-Util-Uniq>.
@@ -216,14 +300,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/List-Util-
 
 Source repository is at L<https://github.com/perlancar/perl-List-Util-Uniq>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=List-Util-Uniq>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<List::Util>
@@ -232,11 +308,37 @@ L<List::Util>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=List-Util-Uniq>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
